package cd.casic.module.machine.dal.mysql;

import cd.casic.framework.commons.pojo.PageResult;
import cd.casic.framework.mybatis.core.mapper.BaseMapperX;
import cd.casic.framework.mybatis.core.query.LambdaQueryWrapperX;
import cd.casic.module.machine.controller.vo.MachineEnvVO;
import cd.casic.module.machine.controller.vo.MachineInfoVO;
import cd.casic.module.machine.dal.dataobject.MachineEnvDO;
import cd.casic.module.machine.dal.dataobject.MachineInfoDO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface MachineInfoMapper extends BaseMapperX<MachineInfoDO> {
    default Boolean existsByTag(String tag){
        return selectOne(new QueryWrapper<MachineInfoDO>().eq("tag", tag))!=null;
    }
    default void updateStatus(Long machineInfoId, Integer status){
        UpdateWrapper<MachineInfoDO> set = new UpdateWrapper<>();
        set.eq("id", machineInfoId).set("status", status);
        this.update(null,set);
    }
    default void bindingSecretKey(List<Long> machineInfoIds, Long secretKeyId){
        LambdaUpdateWrapper<MachineInfoDO> wrapper = new LambdaUpdateWrapper<MachineInfoDO>()
                .set(MachineInfoDO::getSecretKeyId, secretKeyId)
                .in(MachineInfoDO::getId, machineInfoIds);
        this.update(null, wrapper);
    }
    default void unBindingSecretKey(List<Long> secretKeyId){
        LambdaUpdateWrapper<MachineInfoDO> wrapper = new LambdaUpdateWrapper<MachineInfoDO>()
                .set(MachineInfoDO::getSecretKeyId, null)
                .in(MachineInfoDO::getSecretKeyId, secretKeyId);
        this.update(null, wrapper);
    }
    default PageResult<MachineInfoDO> selectPage(MachineInfoVO machineInfoVO){
        return selectPage(machineInfoVO,new LambdaQueryWrapperX<MachineInfoDO>()
                .likeIfPresent(MachineInfoDO::getName, machineInfoVO.getName())
                .likeIfPresent(MachineInfoDO::getTag, machineInfoVO.getTag())
                .likeIfPresent(MachineInfoDO::getDescription, machineInfoVO.getDescription())
                .likeIfPresent(MachineInfoDO::getUsername, machineInfoVO.getUsername())
                .eqIfPresent(MachineInfoDO::getHostIp, machineInfoVO.getHostIp()));
    }


}
